Access [https://github.com/rmrighes/yajaw/releases](https://github.com/rmrighes/yajaw/releases) for release details.

Release history is also available at: 
    [https://pypi.org/project/yajaw/#history](https://pypi.org/project/yajaw/#history).